@@ -1,26 +1,31 @@
-package # hide from pause 
-    Monitoring::Livestatus::Class::Table::Contats;
+package # hide from pause
+    Monitoring::Livestatus::Class::Table::Contacts;
 
 use Moose;
 extends 'Monitoring::Livestatus::Class::Base::Table';
 
+sub build_table_name { return 'contacts' };
+
+sub build_primary_keys { return [qw/name/] };
+
+1;
+__END__
+
 =head1 NAME
 
-Monitoring::Livestatus::Class::Table::Columns - Class for contacts table
+Monitoring::Livestatus::Class::Table::Contacts - Class for contacts table
 
 =head1 METHODS
 
 =head2 build_table_name
 
+=head2 build_primary_keys
+
 Returns the table name from these class.
 
-=cut
-
-sub build_table_name { return 'contacts' };
-
 =head1 AUTHOR
 
-Robert Bohne, C<< <rbo at cpan.org> >>
+See L<Monitoring::Livestatus::Class/AUTHOR> and L<Monitoring::Livestatus::Class/CONTRIBUTORS>.
 
 =head1 COPYRIGHT & LICENSE
 
@@ -32,5 +37,4 @@ by the Free Software Foundation; or the Artistic License.
 
 See http://dev.perl.org/licenses/ for more information.
 
-=cut
-1;
+=cut
\ No newline at end of file
